# Copyright (C) 2012 Collabora Ltd.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

"""
Run apparmor-gstreamer1.0 test suite

Default Options: None
"""

import re

from lava_test.core.installers import TestInstaller
from lava_test.core.runners import TestRunner
from lava_test.core.parsers import TestParser
from lava_test.core.tests import Test

DEPS = ['chaiwala-apparmor-gstreamer1.0-tests']
DEFAULT_OPTIONS = ""
RUNSTEPS = ['su -l chaiwala -c /usr/share/chaiwala-apparmor-gstreamer1.0-tests/lava_run_tests $(OPTIONS)']
# resultdir is optional and probably meaningful only if result is not PASS
PATTERN = "^(?P<test_case_id>.+)\.sh:\s*(?P<result>\w+)\s*-\s*(?P<resultdir>\w+)?.*"
FIXUPS = {
   'PASSED': 'pass',
   'FAILED': 'fail',
   'SKIP': 'skip',
}

class ApparmorDemoParser(TestParser):

    def parse(self, artifacts):
        filename = "testoutput.log"
        pattern = re.compile(self.pattern)
        with open(filename) as stream:
            for lineno, line in enumerate(stream, start=1):
                match = pattern.match(line)
                if not match:
                    continue
                results = match.groupdict()
                test_case_id = results['test_case_id']
                results['test_case_id'] = test_case_id.replace("/", ".")
                results['log_filename'] = "testoutput.log"
                results['log_lineno'] = lineno
                del results['resultdir']
                self.results['test_results'].append(
                    self.analyze_test_result(results))

installer = TestInstaller(deps=DEPS)
runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
parser = ApparmorDemoParser(PATTERN, fixupdict=FIXUPS)

testobj = Test(
    test_id="apparmor-gstreamer1.0",
    installer=installer,
    runner=runner,
    parser=parser)
