# Copyright (C) 2012 Collabora Ltd.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test
import os


VERSION = '0.1'
DEPS = ['chaiwala-tests']
RUNSTEPS = ['sudo service bluetooth start',
            'sudo /usr/lib/chaiwala-tests/bluez/bluez-test',
            #'/usr/lib/chaiwala-tests/bluez/run-obex-test.sh']  # deprecated
           ]
PATTERN = "(?P<test_case_id>[a-z_]+) \([^\(\)]+\) \.\.\. (?P<result>[a-zA-Z]+)"
FIXUPS = {
    "ERROR": "fail",
    "FAIL": "fail",
    "ok": "pass"
}


class BluezParser(TestParser):

    def parse(self, artifacts):
        return self.parse_pathname(
            artifacts.stderr_pathname,
            os.path.relpath(artifacts.stderr_pathname,
                            artifacts.results_dir))


installer = TestInstaller(deps=DEPS)
runner = TestRunner(RUNSTEPS)
parser = BluezParser(PATTERN, fixupdict=FIXUPS)

testobj = Test(
    test_id="bluez",
    test_version=VERSION,
    installer=installer,
    runner=runner,
    parser=parser)
