# Copyright (C) 2012 Collabora Ltd.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

"""
sdk-debug-tools-gdb-smoke-test:
Check basic gdb functionality by stopping a program at a set point and checking
its backtrace matches expectations.

sdk-debug-tools-strace-smoke-test:
Check basic strace functionality by checking its output when run in a simple command
line program.

sdk-debug-tools-valgrind-smoke-test:
Check basic valgrind functionality by running a program with and without memory leaks,
ensuring expected results from valgrind.

**URL:**

**Default options:** None
"""

from lava_test.core.installers import TestInstaller
from lava_test.core.runners import TestRunner
from lava_test.core.parsers import TestParser
from lava_test.core.tests import Test

VERSION='0.1'
DEPS = ['chaiwala-tests']
RUNSTEPS = ['/usr/share/chaiwala-tests/sdk/automated/test-gdb.sh',
            '/usr/share/chaiwala-tests/sdk/automated/test-strace.sh',
            '/usr/share/chaiwala-tests/sdk/automated/test-valgrind.sh']
DEFAULT_OPTIONS = ""
PATTERN = "^(?P<test_case_id>[\w-]+):\W+(?P<result>\w+)$"
FIXUPS={
   'PASSED':'pass',
   'FAILED':'fail'
}

installer = TestInstaller(deps=DEPS)
runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
parser = TestParser(PATTERN, fixupdict=FIXUPS)

testobj = Test(
    test_id="sdk-debug-tools",
    test_version=VERSION,
    installer=installer,
    runner=runner,
    parser=parser)
