# Copyright (C) 2012 Collabora Ltd.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

"""
Run telepathy-gabble test suite

URL: http://cgit.freedesktop.org/telepathy/telepathy-gabble/

Default Options: None
"""

import re

from lava_test.core.installers import TestInstaller
from lava_test.core.runners import TestRunner
from lava_test.core.parsers import TestParser
from lava_test.core.tests import Test

DEPS = ['telepathy-gabble-tests']
DEFAULT_OPTIONS = ""
RUNSTEPS = ['/usr/lib/telepathy-gabble-tests/twisted/run-test.sh $(OPTIONS)']
PATTERN = "^(?P<result>\w+):\s(?P<test_case_id>.+)\.py.*"
FIXUPS={
   'PASS': 'pass',
   'FAIL': 'fail',
   'SKIP': 'skip'
}

class TelepathyGabbleTestsParser(TestParser):

    def parse(self, artifacts):
        filename = "testoutput.log"
        pattern = re.compile(self.pattern)
        with open(filename) as stream:
            for lineno, line in enumerate(stream, start=1):
                match = pattern.match(line)
                if not match:
                    continue
                results = match.groupdict()
                test_case_id = results['test_case_id']
                results['test_case_id'] = test_case_id.replace("/", ".")
                results['log_filename'] = "testoutput.log"
                results['log_lineno'] = lineno
                self.results['test_results'].append(
                    self.analyze_test_result(results))

installer = TestInstaller(deps=DEPS)
runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
parser = TelepathyGabbleTestsParser(PATTERN, fixupdict=FIXUPS)

testobj = Test(
    test_id="telepathy-gabble",
    installer=installer,
    runner=runner,
    parser=parser)
