# Copyright (c) 2012 Collabora Ltd.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import re

from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test

DEPS = ['webkit-clutter-testing', 'webkit-clutter-test-data']
RUNSTEPS = ['/usr/share/webkit_clutter-0/testing/Tools/Scripts/old-run-webkit-tests $(OPTIONS)']
DEFAULT_OPTIONS = "--clutter --out-of-tree --no-launch-safari --verbose"
PATTERN = '^running\s(?P<test_case_id>\S+)\s->\s(?P<result>[\w]+)(\s\(?[\w\s]+\)?)?\s$'
FIXUPS = {
    'succeeded' : 'pass',
    'failed' : 'fail',
    'crashed' : 'fail',
    'new' : 'fail'
}

class WebKitClutterTestsParser(TestParser):
    def parse(self, artifacts):
        filename = "testoutput.log"
        pattern = re.compile(self.pattern)
        with open(filename) as stream:
            for lineno, line in enumerate(stream, start=1):
                match = pattern.match(line)
                if not match:
                    continue
                results = match.groupdict()
                test_case_id = results['test_case_id']
                results['test_case_id'] = test_case_id.replace("/", ".")
                self.results['test_results'].append(self.analyze_test_result(results))

installer = TestInstaller(deps = DEPS)
runner = TestRunner(RUNSTEPS, default_options = DEFAULT_OPTIONS)
parser = WebKitClutterTestsParser(PATTERN, fixupdict = FIXUPS)

testobj = Test(test_id = "webkit-clutter-layout", installer = installer, runner = runner, parser = parser)
